@@ -2,12 +2,14 @@ package types
 
 import (
 	"fmt"
+	"strings"
 
 	"github.com/openshift/installer/pkg/ipnet"
 	"github.com/openshift/installer/pkg/types/aws"
 	"github.com/openshift/installer/pkg/types/azure"
 	"github.com/openshift/installer/pkg/types/baremetal"
 	"github.com/openshift/installer/pkg/types/gcp"
+	"github.com/openshift/installer/pkg/types/kubevirt"
 	"github.com/openshift/installer/pkg/types/libvirt"
 	"github.com/openshift/installer/pkg/types/none"
 	"github.com/openshift/installer/pkg/types/openstack"
@@ -20,7 +22,8 @@ const (
 	// InstallConfigVersion is the version supported by this package.
 	// If you bump this, you must also update the list of convertable values in
 	// pkg/types/conversion/installconfig.go
-	InstallConfigVersion = "v1"
+	InstallConfigVersion  = "v1"
+	workerMachinePoolName = "worker"
 )
 
 var (
@@ -40,6 +43,7 @@ var (
 	// to the user in the interactive wizard.
 	HiddenPlatformNames = []string{
 		baremetal.Name,
+		kubevirt.Name,
 		none.Name,
 	}
 )
@@ -134,15 +138,15 @@ type InstallConfig struct {
 	// For each of the following platforms, the field can set to the specified values. For all other platforms, the
 	// field must not be set.
 	// AWS: "Mint", "Passthrough", "Manual"
-	// Azure: "Mint", "Passthrough"
-	// GCP: "Mint", "Passthrough"
+	// Azure: "Mint", "Passthrough", "Manual"
+	// GCP: "Mint", "Passthrough", "Manual"
 	// +optional
 	CredentialsMode CredentialsMode `json:"credentialsMode,omitempty"`
 }
 
 // ClusterDomain returns the DNS domain that all records for a cluster must belong to.
 func (c *InstallConfig) ClusterDomain() string {
-	return fmt.Sprintf("%s.%s", c.ObjectMeta.Name, c.BaseDomain)
+	return fmt.Sprintf("%s.%s", c.ObjectMeta.Name, strings.TrimSuffix(c.BaseDomain, "."))
 }
 
 // Platform is the configuration for the specific platform upon which to perform
@@ -183,6 +187,10 @@ type Platform struct {
 	// Ovirt is the configuration used when installing on oVirt.
 	// +optional
 	Ovirt *ovirt.Platform `json:"ovirt,omitempty"`
+
+	// Kubevirt is the configuration used when installing on kubevirt.
+	// +optional
+	Kubevirt *kubevirt.Platform `json:"kubevirt,omitempty"`
 }
 
 // Name returns a string representation of the platform (e.g. "aws" if
@@ -210,6 +218,8 @@ func (p *Platform) Name() string {
 		return vsphere.Name
 	case p.Ovirt != nil:
 		return ovirt.Name
+	case p.Kubevirt != nil:
+		return kubevirt.Name
 	default:
 		return ""
 	}
@@ -246,7 +256,7 @@ type Networking struct {
 	// +optional
 	ServiceNetwork []ipnet.IPNet `json:"serviceNetwork,omitempty"`
 
-	// Deprected types, scheduled to be removed
+	// Deprecated types, scheduled to be removed
 
 	// Deprecated name for MachineCIDRs. If set, MachineCIDRs must
 	// be empty or the first index must match.
@@ -257,7 +267,7 @@ type Networking struct {
 	// +optional
 	DeprecatedType string `json:"type,omitempty"`
 
-	// Depcreated name for ServiceNetwork
+	// Deprecated name for ServiceNetwork
 	// +optional
 	DeprecatedServiceCIDR *ipnet.IPNet `json:"serviceCIDR,omitempty"`
 
@@ -279,8 +289,10 @@ type ClusterNetworkEntry struct {
 	CIDR ipnet.IPNet `json:"cidr"`
 
 	// HostPrefix is the prefix size to allocate to each node from the CIDR.
-	// For example, 24 would allocate 2^8=256 adresses to each node.
-	HostPrefix int32 `json:"hostPrefix"`
+	// For example, 24 would allocate 2^8=256 adresses to each node. If this
+	// field is not used by the plugin, it can be left unset.
+	// +optional
+	HostPrefix int32 `json:"hostPrefix,omitempty"`
 
 	// The size of blocks to allocate from the larger pool.
 	// This is the length in bits - so a 9 here will allocate a /23.
@@ -330,3 +342,14 @@ const (
 	// cloud credentials for each CredentialsRequest.
 	PassthroughCredentialsMode CredentialsMode = "Passthrough"
 )
+
+// WorkerMachinePool retrieves the worker MachinePool from InstallConfig.Compute
+func (c *InstallConfig) WorkerMachinePool() *MachinePool {
+	for _, machinePool := range c.Compute {
+		if machinePool.Name == workerMachinePoolName {
+			return &machinePool
+		}
+	}
+
+	return nil
+}
